isLargerThan method

bool isLargerThan(
  1. BreakpointId other
)

Checks if this breakpoint represents a width category larger than the other breakpoint, based on their minWidth from DefaultBreakpoints.

Implementation

bool isLargerThan(BreakpointId other) {
  return _getMinWidthFor(this) > _getMinWidthFor(other);
}