isSmallerOrEqualTo method

bool isSmallerOrEqualTo(
  1. BreakpointId other
)

Checks if this breakpoint represents a width category smaller than or equal to the other breakpoint, based on their minWidth from DefaultBreakpoints.

Implementation

bool isSmallerOrEqualTo(BreakpointId other) {
  return _getMinWidthFor(this) <= _getMinWidthFor(other);
}