isSmallerThan method

bool isSmallerThan(
  1. BreakpointId other
)

Checks if this breakpoint represents a width category smaller than the other breakpoint, based on their minWidth from DefaultBreakpoints.

Implementation

bool isSmallerThan(BreakpointId other) {
  return _getMinWidthFor(this) < _getMinWidthFor(other);
}